Crate mssf_core

Crate mssf_core 

Features

All features are enabled by default unless otherwise noted. For most scenarios, you’ll want the features. However, in some scenarios, such as:

  • integrating Rust into an existing Service Fabric Application written in another language
  • when you are using the lower-level COM API to do something more custom You might not need all of the functionality that the mssf-core crate provides In this case, you can configure only what you need to reduce dependencies and compile times.
  • ** config_source ** - Provides an implementation of config::Source. Requires config_rs crate

  • ** Tokio ** - A lot of the sophoisticated functionality in this crate requires Tokio. However, even without tokio, some of the higher level wrappers over COM types have utility.

SF COM API Versions

The minimum supported SF version for mssf is 10.1. mssf can be used on newer versions of SF, but some APIs are not available.

Re-exports

pub use api::API_TABLE;

Modules

api
Dynamically load SF libs and c functions. SF shared lib provides these functions, and we dynamically load them here so that user of this crate does not need to worry about installing SF lib and linking, which can be complex.
client
conf
debug
iter
mem
runtime
strings
sync
types

Structs

Error
Make passing error code to SF api easier. Provides conversion from windows errors or fabric error code to windows_core::Error. All safe code uses this Error, and bridge and proxy code needs to convert this Error into/from WinError.
GUID
A globally unique identifier (GUID).
HRESULT
An error code value returned by most COM functions.
PCWSTR
A pointer to a constant null-terminated UTF-16 string.
WString
WString is the utf16 string, similar to std::wstring in cpp. It is used for passing utf16 string buffers between Rust and COM.
WinError
Windows error type. A Windows error code with optional COM error information.

Enums

ErrorCode

Traits

Interface
Provides low-level access to a COM interface vtable.

Type Aliases

Ref
The parameter type for a generic type T used in _Impl trait method signatures.
Result
Result containing mssf Error.
WinResult
A specialized Result type that provides Windows error information.

Attribute Macros

async_trait
Re-export async_trait for use in defining async traits in mssf-core