pub struct ApplicationManagementClient { /* private fields */ }Expand description
Provides functionality to perform application management operations, such as querying application upgrade progress.
See C# API here.
We are only adding support for application upgrade progress for now - additional functionality can be added later.
Implementations
Sourceimpl ApplicationManagementClient
impl ApplicationManagementClient
Sourcepub async fn get_application_upgrade_progress(
&self,
application_name: &Uri,
timeout: Duration,
cancellation_token: Option<BoxedCancelToken>,
) -> Result<ApplicationUpgradeProgress>
pub async fn get_application_upgrade_progress( &self, application_name: &Uri, timeout: Duration, cancellation_token: Option<BoxedCancelToken>, ) -> Result<ApplicationUpgradeProgress>
Gets the upgrade progress for the specified application.
Equivalent of the Get-ServiceFabricApplicationUpgrade PowerShell cmdlet.
The returned ApplicationUpgradeProgress includes the aggregate
upgrade state as well as the per upgrade-domain status.
Remarks: SF returns a valid result even for applications that are not
currently upgrading; check ApplicationUpgradeProgress::is_active to
determine whether an upgrade is in flight.