pub trait GetRawWithBoxPool<T> {
// Required method
fn get_raw_with_pool(&self, pool: &mut BoxPool) -> T;
}Expand description
Trait to get a raw pointer from a type, using a BoxPool to hold the box. This is useful to implement conversions to raw COM types that require raw pointers in struct fields.
Required Methods
fn get_raw_with_pool(&self, pool: &mut BoxPool) -> T
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".