Re-exports
pub use self::runtime_wrapper::Runtime;
Modules
- config
- error
- executor
- node_
context - package_
change - This module supports implementing callbacks when Service Fabric Packages are changed
- runtime_
wrapper - self_
reconfiguring_ bridge - stateful_
bridge - stateful_
proxy - stateless_
bridge - store
- store_
proxy
Structs
- Code
Package Activation Context - Code
Package Info - Code package information is propagated here from the ActivationContext provided when the service is started. This information can be used to setup log directories and other resources needed which require information about the code package and the local runtime environment.
- Self
Reconfiguring Service Partition - Wrapper for the
IFabricSelfReconfiguringServicePartitionCOM interface. - Stateless
Service Partition
Traits
- IPrimary
Replicator - TODO: primary replicator has no public documentation, this is gathered unofficially and is subject to change/correction. IFabricPrimaryReplicator com interface wrapper.
- IReplicator
- TODO: replicator has no public documentation
- ISelf
Reconfiguring Service Factory - Represents a self-reconfiguring service factory that is responsible for
creating instances of a specific type of self-reconfiguring service.
Self-reconfiguring service factories are registered with the FabricRuntime by
service hosts via
Runtime::register_self_reconfiguring_service_factory(). - ISelf
Reconfiguring Service Instance - Safe abstraction over the
IFabricSelfReconfiguringServiceInstanceCOM interface that an author implements. Each method corresponds to a method on that COM interface;openandcloseare asynchronous (COM Begin/End), the rest are synchronous. - ISelf
Reconfiguring Service Partition - Safe abstraction over the
IFabricSelfReconfiguringServicePartitionCOM interface. Each method corresponds to a synchronous method on that interface. - IStateful
Service Factory - Represents a stateful service factory that is responsible for creating replicas of a specific type of stateful service. Stateful service factories are registered with the FabricRuntime by service hosts via register_stateful_service_factory().
- IStateful
Service Partition - IStateful
Service Replica - Defines behavior that governs the lifecycle of a replica, such as startup, initialization, role changes, and shutdown. Remarks: Stateful service types must implement this interface. The logic of a stateful service type includes behavior that is invoked on primary replicas and behavior that is invoked on secondary replicas.
- IStateless
Service Factory - Stateless service factories are registered with the FabricRuntime by service hosts via Runtime::register_stateless_service_factory().
- IStateless
Service Instance - Defines behavior that governs the lifecycle of a stateless service instance, such as startup, initialization, and shutdown.
- IStateless
Service Partition - Abstrction for IFStatelessServicePartition interface