pub struct Error { /* private fields */ }Expand description
Make passing error code to SF api easier. Provides conversion from windows errors or fabric error code to windows_core::Error. All safe code uses this Error, and bridge and proxy code needs to convert this Error into/from WinError.
Implementations
Sourceimpl Error
impl Error
pub fn new(code: HRESULT, msg: Option<WString>) -> Self
Sourcepub fn from_hresult(code: HRESULT) -> Self
pub fn from_hresult(code: HRESULT) -> Self
Create error from HRESULT code only, with no message.
Sourcepub fn try_as_fabric_error_code(&self) -> Result<ErrorCode, &str>
pub fn try_as_fabric_error_code(&self) -> Result<ErrorCode, &str>
Convert to fabric error code if possible.
Sourcepub fn from_thread(code: HRESULT) -> Self
pub fn from_thread(code: HRESULT) -> Self
Create error from current thread last error code and message.
pub fn code(&self) -> HRESULT