Module runtime

Module runtime 

Re-exports

pub use self::runtime_wrapper::Runtime;

Modules

config
error
executor
node_context
package_change
This module supports implementing callbacks when Service Fabric Packages are changed
runtime_wrapper
stateful_bridge
stateful_proxy
stateless_bridge
store
store_proxy

Structs

CodePackageActivationContext
CodePackageInfo
Code package information is propagated here from the ActivationContext provided when the service is started. This information can be used to setup log directories and other resources needed which require information about the code package and the local runtime environment.
StatelessServicePartition

Traits

IPrimaryReplicator
TODO: primary replicator has no public documentation, this is gathered unofficially and is subject to change/correction. IFabricPrimaryReplicator com interface wrapper.
IReplicator
TODO: replicator has no public documentation
IStatefulServiceFactory
Represents a stateful service factory that is responsible for creating replicas of a specific type of stateful service. Stateful service factories are registered with the FabricRuntime by service hosts via register_stateful_service_factory().
IStatefulServicePartition
IStatefulServiceReplica
Defines behavior that governs the lifecycle of a replica, such as startup, initialization, role changes, and shutdown. Remarks: Stateful service types must implement this interface. The logic of a stateful service type includes behavior that is invoked on primary replicas and behavior that is invoked on secondary replicas.
IStatelessServiceFactory
Stateless service factories are registered with the FabricRuntime by service hosts via Runtime::register_stateless_service_factory().
IStatelessServiceInstance
Defines behavior that governs the lifecycle of a stateless service instance, such as startup, initialization, and shutdown.
IStatelessServicePartition
Abstrction for IFStatelessServicePartition interface

Functions

create_com_runtime
get_com_activation_context