ISelfReconfiguringServicePartition

Trait ISelfReconfiguringServicePartition 

pub trait ISelfReconfiguringServicePartition:
    Send
    + Sync
    + 'static {
    // Required methods
    fn get_partition_info(&self) -> Result<ServicePartitionInformation>;
    fn report_load(&self, metrics: &[LoadMetric]) -> Result<()>;
    fn report_fault(&self, fault_type: FaultType) -> Result<()>;
    fn report_move_cost(&self, move_cost: MoveCost) -> Result<()>;
    fn report_instance_health(
        &self,
        health_info: &HealthInformation,
    ) -> Result<()>;
    fn report_partition_health(
        &self,
        health_info: &HealthInformation,
    ) -> Result<()>;
    fn report_configuration(
        &self,
        report: &SelfReconfiguringConfigurationReport,
    ) -> Result<()>;
}
Safe abstraction over the IFabricSelfReconfiguringServicePartition COM interface. Each method corresponds to a synchronous method on that interface.

Required Methods

fn get_partition_info(&self) -> Result<ServicePartitionInformation>

Provides access to the ServicePartitionInformation of the service, which contains the partition type and ID.

fn report_load(&self, metrics: &[LoadMetric]) -> Result<()>

Reports load for the current instance in the partition.

fn report_fault(&self, fault_type: FaultType) -> Result<()>

Enables the instance to report a fault to the runtime and indicates that it has encountered an error from which it cannot recover and must either be restarted or removed.

fn report_move_cost(&self, move_cost: MoveCost) -> Result<()>

Reports the move cost for an instance.

fn report_instance_health(&self, health_info: &HealthInformation) -> Result<()>

Reports health on the current self-reconfiguring service instance of the partition.

fn report_partition_health(&self, health_info: &HealthInformation) -> Result<()>

Reports current partition health.

fn report_configuration( &self, report: &SelfReconfiguringConfigurationReport, ) -> Result<()>

Public documentation for this interface is TBD.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors